pub enum ImportFunctionKind {
Method {
class: String,
ty: Type,
kind: MethodKind,
},
Normal,
}Expand description
The type of a function being imported
Variants
Method
Fields
class: StringThe name of the class for this method, in JS
ty: TypeThe type of the class for this method, in Rust
kind: MethodKindThe kind of method this is
A class method
Normal
A standard function